The highest tagged major version is
v6.
package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Dec 9, 2017
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ChangePassword struct {
VaultPath string
}
type Delete struct {
Id uuid.UUID
VaultPath string
}
type Edit struct {
Id uuid.UUID
VaultPath string
}
type Initialize struct {
VaultPath string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.